@@ -2,11 +2,11 @@ from abc import abstractmethod
 
 from api.handler.ILogAbleHandler import ILogAbleHandler
 from api.handler.script.ICacheAbleScript import ICacheAbleScript
-from api.handler.script.IKillableScript import IKillableScript
+from api.handler.IKillable import IKillable
 from api.model.FdInputPipe import FdInputPipe
 
 
-class ISimpleScriptCE(IKillableScript,ILogAbleHandler,ICacheAbleScript):
+class ISimpleScriptCE(IKillable, ILogAbleHandler, ICacheAbleScript):
     """
     Python脚本式的CE的基类
     """
@@ -20,3 +20,10 @@ class ISimpleScriptCE(IKillableScript,ILogAbleHandler,ICacheAbleScript):
         :return: 返回一个 OutputWrapper的 数组
         """
         pass
+
+    def is_killed(self)->bool:
+        """
+        判断是否杀掉了
+        :return:
+        """
+        return False
\ No newline at end of file
